<!DOCTYPE HTML>
<html>
	<head>
	<meta charset="utf-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<title>Complex Template</title>
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<meta name="description" content="" />
	<meta name="keywords" content="" />
	<meta name="author" content="" />

  <!-- Facebook and Twitter integration -->
	<meta property="og:title" content=""/>
	<meta property="og:image" content=""/>
	<meta property="og:url" content=""/>
	<meta property="og:site_name" content=""/>
	<meta property="og:description" content=""/>
	<meta name="twitter:title" content="" />
	<meta name="twitter:image" content="" />
	<meta name="twitter:url" content="" />
	<meta name="twitter:card" content="" />

	<link href="https://fonts.googleapis.com/css?family=Poppins:200,300,400,500,700" rel="stylesheet">
	
	<!-- Animate.css -->
	<link rel="stylesheet" href="css/animate.css">
	<!-- Icomoon Icon Fonts-->
	<link rel="stylesheet" href="css/icomoon.css">
	<!-- Bootstrap  -->
	<link rel="stylesheet" href="css/bootstrap.css">

	<!-- Magnific Popup -->
	<link rel="stylesheet" href="css/magnific-popup.css">

	<!-- Flexslider  -->
	<link rel="stylesheet" href="css/flexslider.css">

	<!-- Owl Carousel -->
	<link rel="stylesheet" href="css/owl.carousel.min.css">
	<link rel="stylesheet" href="css/owl.theme.default.min.css">
	
	<!-- Flaticons  -->
	<link rel="stylesheet" href="fonts/flaticon/font/flaticon.css">

	<!-- Theme style  -->
	<link rel="stylesheet" href="css/style.css">

	<!-- Modernizr JS -->
	<script src="js/modernizr-2.6.2.min.js"></script>
	<!-- FOR IE9 below -->
	<!--[if lt IE 9]>
	<script src="js/respond.min.js"></script>
	<![endif]-->

	</head>
	<body>
		
	<div class="colorlib-loader"></div>

	<div id="page">
		<nav class="colorlib-nav" role="navigation">
			<div class="top-menu">
				<div class="container">
					<div class="row">
						<div class="col-xs-2">
							<div id="colorlib-logo"><a href="index.html">Complex</a></div>
						</div>
						<div class="col-xs-10 text-right menu-1">
							<ul>
								<li><a href="index.html">Home</a></li>
								<li class="has-dropdown active">
									<a href="project.html">Projects</a>
									<ul class="dropdown">
										<li><a href="#">Commercial</a></li>
										<li><a href="#">Apartment</a></li>
										<li><a href="#">House</a></li>
										<li><a href="#">Building</a></li>
									</ul>
								</li>
								<li><a href="services.html">Services</a></li>
								<li><a href="blog.html">Blog</a></li>
								<li><a href="about.html">About</a></li>
								<li><a href="contact.html">Contact</a></li>
							</ul>
						</div>
					</div>
				</div>
			</div>
		</nav>
		<aside id="colorlib-hero">
			<div class="flexslider">
				<ul class="slides">
			   	<li style="background-image: url(images/cover_img_3.jpg);">
			   		<div class="overlay"></div>
			   		<div class="container-fluid">
			   			<div class="row">
				   			<div class="col-md-8 col-sm-12 col-md-offset-2 slider-text">
				   				<div class="slider-text-inner text-center">
				   					<h1>Project</h1>
				   					<h2><a href="index.html">Home</a> - <a href="project.html">Project</a> - Project Single</h2>
				   				</div>
				   			</div>
				   		</div>
			   		</div>
			   	</li>
			  	</ul>
		  	</div>
		</aside>
		
		<div id="colorlib-project">
			<div class="container">
				<div class="row row-pb-lg">
					<div class="col-md-8 animate-box">
						<img class="img-responsive project-single" src="images/building-7.jpg" alt="html5 bootstrap template by colorlib.com">
						<div class="thumb-wrap">
							<div class="row">
								<div class="col-md-3 col-sm-3 col-xs-6">
									<a href="#" class="thumb-img" style="background-image: url(images/building-8.jpg);"></a>
								</div>
								<div class="col-md-3 col-sm-3 col-xs-6">
									<a href="#" class="thumb-img" style="background-image: url(images/building-9.jpg);"></a>
								</div>
								<div class="col-md-3 col-sm-3 col-xs-6">
									<a href="#" class="thumb-img" style="background-image: url(images/building-10.jpg);"></a>
								</div>
								<div class="col-md-3 col-sm-3 col-xs-6">
									<a href="#" class="thumb-img" style="background-image: url(images/building-12.jpg);"></a>
								</div>
							</div>
						</div>
					</div>
					<div class="col-md-4 animate-box">
						<div class="project-single-desc">
							<h2>Project Details</h2>
							<ul class="list">
								<li><span class="title">Client:</span> <span class="title-2">Complex.ltd</span></li>
								<li><span class="title">Location:</span> <span class="title-2">USA, California</span></li>
								<li><span class="title">Budget:</span> <span class="title-2">$400,000</span></li>
								<li><span class="title">Surface Area:</span> <span class="title-2">15800 sf2</span></li>
								<li><span class="title">Construction Area:</span> <span class="title-2">Construction</span></li>
							</ul>
						</div>
						<p class="downloadreport text-center"><a href="#"><i class="icon-download3"></i> Download Project Report</a></p>
					</div>
				</div>
				<div class="row row-pb-lg">
					<div class="col-md-4 animate-box">
						<h3>Contruction</h3>
						<p>A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth.</p>
					</div>
					<div class="col-md-4 animate-box">
						<h3>Project Description</h3>
						<p>A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth.</p>
					</div>
					<div class="col-md-4 animate-box">
						<h3>Important Facts</h3>
						<p>A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth.</p>
					</div>
				</div>
				<div class="row">
					<div class="col-md-8 col-md-offset-2 text-center colorlib-heading animate-box">
						<h2>related Projects</h2>
						<p>Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name</p>
					</div>
				</div>
				<div class="row">
					<div class="col-md-4 animate-box">
						<div class="project-entry">
							<a href="project.html" class="project-img text-center" style="background-image: url(images/building-4.jpg);">
								<span class="icon"><i class="icon-search2"></i></span>
							</a>
							<div class="desc">
								<h3><a href="project.html">Kitchen Interior</a></h3>
							</div>
						</div>
					</div>
					<div class="col-md-4 animate-box">
						<div class="project-entry">
							<a href="project.html" class="project-img text-center" style="background-image: url(images/building-5.jpg);">
								<span class="icon"><i class="icon-search2"></i></span>
							</a>
							<div class="desc">
								<h3><a href="project.html">Commercial Building</a></h3>
							</div>
						</div>
					</div>
					<div class="col-md-4 animate-box">
						<div class="project-entry">
							<a href="project.html" class="project-img text-center" style="background-image: url(images/building-6.jpg);">
								<span class="icon"><i class="icon-search2"></i></span>
							</a>
							<div class="desc">
								<h3><a href="project.html">Hotel Building</a></h3>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		
		<div id="colorlib-subscribe">
			<div class="overlay"></div>
			<div class="container">
				<div class="row">
					<div class="col-md-8 col-md-offset-2 text-center colorlib-heading animate-box">
						<h2>Subscribe Newsletter</h2>
						<p>Subscribe our newsletter and get latest update</p>
					</div>
				</div>
				<div class="row animate-box">
					<div class="col-md-6 col-md-offset-3">
						<div class="row">
							<form class="form-inline qbstp-header-subscribe">
								<div class="col-three-forth">
									<div class="form-group">
										<input type="text" class="form-control" id="email" placeholder="Enter your email">
									</div>
								</div>
								<div class="col-one-third">
									<div class="form-group">
										<button type="submit" class="btn btn-primary">Subscribe Now</button>
									</div>
								</div>
							</form>
						</div>
					</div>
				</div>
			</div>
		</div>
		<footer id="colorlib-footer">
			<div class="contact-information">
				<div class="container">
					<div class="row">
						<div class="col-md-8 col-md-offset-2">
							<div class="row">
								<div class="col-md-4 text-center">
									<div class="info-wrap">
										<span class="icon"><i class="icon-location4"></i></span>
										<p>291 South 21th Street, <br> Suite 721 New York NY 10016</p>
									</div>
								</div>
								<div class="col-md-4 text-center">
									<div class="info-wrap">
										<span class="icon"><i class="icon-world"></i></span>
										<p><a href="#">info@example.com</a> <br> <a href="#">www.example.com</a></p>
									</div>
								</div>
								<div class="col-md-4 text-center">
									<div class="info-wrap">
										<span class="icon"><i class="icon-phone2"></i></span>
										<p><a href="#">(001) 2345 6789</a> <br> <a href="#">(001) 9876 5432</a></p>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="container">
				<div class="row row-pb-md">
					<div class="col-md-3 colorlib-widget">
						<h4>About Complex</h4>
						<p>Far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics</p>
						<p>
							<ul class="colorlib-social-icons">
								<li><a href="#"><i class="icon-twitter"></i></a></li>
								<li><a href="#"><i class="icon-facebook"></i></a></li>
								<li><a href="#"><i class="icon-linkedin"></i></a></li>
								<li><a href="#"><i class="icon-dribbble"></i></a></li>
							</ul>
						</p>
					</div>
					<div class="col-md-3 col-md-push-1 colorlib-widget">
						<h4>Information</h4>
						<p>
							<ul class="colorlib-footer-links">
								<li><a href="#"><i class="icon-check"></i> Our Company</a></li>
								<li><a href="#"><i class="icon-check"></i> Certification</a></li>
								<li><a href="#"><i class="icon-check"></i> Our services</a></li>
								<li><a href="#"><i class="icon-check"></i> Career</a></li>
								<li><a href="#"><i class="icon-check"></i> Core Values</a></li>
								<li><a href="#"><i class="icon-check"></i> Company History</a></li>
								<li><a href="#"><i class="icon-check"></i> FAQ</a></li>
							</ul>
						</p>
					</div>

					<div class="col-md-3 colorlib-widget">
						<h4>Instagram</h4>
						<div class="instagram">
							<a href="#" class="insta-img" style="background-image: url(images/building-1.jpg);"></a>
							<a href="#" class="insta-img" style="background-image: url(images/building-2.jpg);"></a>
							<a href="#" class="insta-img" style="background-image: url(images/building-3.jpg);"></a>
							<a href="#" class="insta-img" style="background-image: url(images/building-4.jpg);"></a>
							<a href="#" class="insta-img" style="background-image: url(images/building-5.jpg);"></a>
							<a href="#" class="insta-img" style="background-image: url(images/building-6.jpg);"></a>
						</div>
					</div>

					<div class="col-md-3 col-md-push-1 colorlib-widget">
						<h4>Contact Info</h4>
						<ul class="colorlib-footer-links">
							<li>291 South 21th Street, <br> Suite 721 New York NY 10016</li>
							<li><a href="tel://1234567920"><i class="icon-phone"></i> + 1235 2355 98</a></li>
							<li><a href="mailto:info@yoursite.com"><i class="icon-envelope"></i> info@yoursite.com</a></li>
							<li><a href="http://luxehotel.com"><i class="icon-location4"></i> yourwebsite.com</a></li>
						</ul>
					</div>
				</div>
			</div>
			<div class="copy">
				<div class="container">
					<div class="row">
						<div class="col-md-12 text-center">
							<p>
								<small class="block">
									<!-- Link back to Colorlib can't be removed. Template is licensed under CC BY 3.0. -->
Copyright &copy;<script>document.write(new Date().getFullYear());</script> | Made with <i class="icon-heart3" aria-hidden="true"></i> by <a href="https://colorlib.com" target="_blank">Colorlib</a> &amp; distributed by <a href="https://themewagon.com" target="_blank">ThemeWagon</a>
<!-- Link back to Colorlib can't be removed. Template is licensed under CC BY 3.0. -->
								</small>
							</p>
						</div>
					</div>
				</div>
			</div>
		</footer>
	</div>

	<div class="gototop js-top">
		<a href="#" class="js-gotop"><i class="icon-arrow-up2"></i></a>
	</div>
	
	<!-- jQuery -->
	<script src="js/jquery.min.js"></script>
	<!-- jQuery Easing -->
	<script src="js/jquery.easing.1.3.js"></script>
	<!-- Bootstrap -->
	<script src="js/bootstrap.min.js"></script>
	<!-- Waypoints -->
	<script src="js/jquery.waypoints.min.js"></script>
	<!-- Stellar Parallax -->
	<script src="js/jquery.stellar.min.js"></script>
	<!-- Flexslider -->
	<script src="js/jquery.flexslider-min.js"></script>
	<!-- Owl carousel -->
	<script src="js/owl.carousel.min.js"></script>
	<!-- Magnific Popup -->
	<script src="js/jquery.magnific-popup.min.js"></script>
	<script src="js/magnific-popup-options.js"></script>
	<!-- Counters -->
	<script src="js/jquery.countTo.js"></script>
	<!-- Main -->
	<script src="js/main.js"></script>

	</body>
</html>

